import React, {Component} from 'react';
import { View, TouchableOpacity, ScrollView } from 'react-native';
import { connect } from 'react-redux';
import {RTCView} from 'react-native-webrtc';
import { Platform } from '../react';

class ThumbnailView extends Component{
    constructor(props){
        super(props);
    }

    render(){
        return(
            <ScrollView contentContainerStyle={this.style.lt_container} scrollEnabled={true} showsVerticalScrollIndicator={true} style={ this.style.container }>
                <View style={this.style.lt_container}>
                {
                    this.props.localTracks.map((track,index) => {
                        if(track.type == "video" && this.props.remoteTracks.length > 0 && this.props.dominantVideoId != 'localVideo'){
                            return (
                                <TouchableOpacity key={index} onPress={()=>{this.props.updateDominantVideoId('localVideo')}}>
                                    <RTCView
                                        key={index}
                                        objectFit = "cover"
                                        streamURL = { track.getOriginalStream().toURL() }
                                        style={{ height: 100, width: 100, margin: 10}}
                                        zOrder={1}
                                    />
                                </TouchableOpacity>
                            )
                        }
                    })
                }
                {
                    this.props.remoteTracks.map((tracks,index) => {
                        if(tracks.ownerId != this.props.dominantVideoId && tracks.video != null){            
                            return (
                                <TouchableOpacity key={index} onPress={()=>{this.props.updateDominantVideoId(tracks.ownerId)}}>
                                    <RTCView
                                        key={index}
                                        objectFit = "cover"
                                        streamURL = {tracks.video.getOriginalStream().toURL()}
                                        zOrder={1}
                                        style={{ height: 100, width: 100, margin: 10}} 
                                    />
                                </TouchableOpacity>
                            )
                        }
                    })
                }
                </View>
            </ScrollView>
        )
    }

    style = {
        lt_container : { display:'flex', flexDirection: 'column-reverse', alignItems: 'flex-end', bottom: 0 },
        container: Platform.OS === 'ios' ? { display: 'flex', flex: 1, zIndex: 999, alignSelf: 'flex-end' }  : { }
    };
}

function mapStateToProps (state) {
    return {
        localurl: state.url.localUrl,
        localTracks: state.tracks.localTracks,
        remoteTracks: state.tracks.remoteTracks,
        dominantVideoId: state.tracks.dominantVideoId
    }
}

function mapDispatchToProps(dispatch){
    return{
        updateDominantVideoId: (id) => dispatch(data.updateDominantVideoId(id))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(ThumbnailView)