(global = function(){
    if (typeof global.$ === 'undefined') {
        const jQuery = require('jquery');
        jQuery(global);
        global.$ = jQuery;
    }
})(global || window || this);


import '../native';
import { Component } from 'react';
import { Alert } from 'react-native';
import JitsiMeetJS from 'lib-jitsi-meet/lib-jitsi-meet.min';
import data from '../actions';

export default class JitsiManager extends Component{

    static localVideoUrl = '';

    static roomName = null;

    static dispatch = null;

    static onMuteAudio (){
        this.localTracks[0].mute();
    }
    
    static onUnmuteAudio (){
        this.localTracks[0].unmute();
    }

    static onMuteVideo (){
         this.localTracks[1].mute();
    }

    static onUnmuteVideo (){
        this.localTracks[1].unmute();
    }

    static connection = null;

    static room = null;

    static localTracks = [];
    
    static isJoined = true;

    static confOptions = {
        openBridgeChannel: true
    };

    static remoteTracks = {};

    static initOptions = {
        disableAudioLevels: true,
        desktopSharingChromeExtId: 'mbocklcggfhnbahlnepmldehdhpjfcjp',
        desktopSharingChromeDisabled: false,
        desktopSharingChromeSources: [ 'screen', 'window' ],
        desktopSharingChromeMinExtVersion: '0.1',
        desktopSharingFirefoxDisabled: true
    };

    static options = {
        hosts: {
          domain: 'caesar.cometchat.com',
          muc: 'conference.caesar.cometchat.com'
        },
        bosh: 'https://caesar.cometchat.com/http-bind',
        clientNode: 'http://jitsi.org/jitsimeet'
      };

    static onConnectionSuccess() {
        this.room = this.connection.initJitsiConference(this.roomName, this.confOptions);
        this.room.on(JitsiMeetJS.events.conference.TRACK_ADDED, this.onRemoteTrack);
        this.room.on(JitsiMeetJS.events.conference.TRACK_REMOVED, track = function() { console.info('track'); });
        this.room.on(JitsiMeetJS.events.conference.CONFERENCE_JOINED, this.onConferenceJoined);
        this.room.on(JitsiMeetJS.events.conference.USER_JOINED, id = function(){ console.log("User Joined") });
        this.room.on(JitsiMeetJS.events.conference.USER_LEFT, this.onUserLeft);
        this.room.on(JitsiMeetJS.events.conference.TRACK_MUTE_CHANGED, track = function(){ console.info('track'); });
        this.room.on(JitsiMeetJS.events.conference.DISPLAY_NAME_CHANGED, function(userID, displayName){ console.info('displayName')});
        this.room.on(JitsiMeetJS.events.conference.TRACK_AUDIO_LEVEL_CHANGED, function(userID, audioLevel) { console.info('audioLevel')});
        this.room.join();
    }

    static onLocalTracks(tracks) {
        this.localTracks = tracks;
        this.dispatch(data.addLocalTracks(this.localTracks));        
        for (let i = 0; i < this.localTracks.length; i++) {
            this.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_LEVEL_CHANGED, audioLevel = function() { console.info('audioLevel')});
            this.localTracks[i].addEventListener(JitsiMeetJS.events.track.TRACK_MUTE_CHANGED, function() {console.info('local track muted')});
            this.localTracks[i].addEventListener(JitsiMeetJS.events.track.LOCAL_TRACK_STOPPED, function() {console.info('track stopped')});
            this.localTracks[i].addEventListener(JitsiMeeˀtJS.events.track.TRACK_AUDIO_OUTPUT_CHANGED, deviceId =function(){ console.info('deviceId')}); 
            if (this.localTracks[i].getType() === 'video') {
                this.dispatch(data.addLocalUrl(this.localTracks[i].getOriginalStream().toURL()));
                this.dispatch(data.addLocalTrackId(this.localTracks[i].ownerEndpointId));    
            }
            if (!this.isJoined) {
                this.room.addTrack(this.localTracks[i]);
            }
        }
    }

    static onRemoteTrack(track) {
        if (track.isLocal()) {
            return;
        }
        this.dispatch(data.addRemoteTracks(track));
        const participant = track.getParticipantId();
        if (!this.remoteTracks[participant]) {
            this.remoteTracks[participant] = [];
        }
        const idx = this.remoteTracks[participant].push(track);
        track.addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_LEVEL_CHANGED,audioLevel = function() {console.info('audioLevel')});
        track.addEventListener(JitsiMeetJS.events.track.TRACK_MUTE_CHANGED,function() {console.info('')});
        track.addEventListener(JitsiMeetJS.events.track.LOCAL_TRACK_STOPPED,function() {console.info('')});
        track.addEventListener(JitsiMeetJS.events.track.TRACK_AUDIO_OUTPUT_CHANGED,deviceId = function(){console.info('deviceId')});
        const id = participant + track.getType() + idx;
        if (track.getType() === 'video') {
            this.dispatch(data.addRemoteUrl(track.getOriginalStream().toURL()));
        } else {
            //$('.remoteVideo').append(`<audio autoplay='1' id='${participant}audio${idx}' />`);
        }
        //track.attach($('#'+id)[0]);
    }

    static onConferenceJoined() {
        this.isJoined = true;
        for (let i = 0; i < this.localTracks.length; i++) {
            this.room.addTrack(this.localTracks[i]);
        }
    }

    static onUserLeft(id) {
        if (!this.remoteTracks[id]) {
            return;
        }
        this.dispatch(data.removeRemoteTrack(id));
    }

    static onConnectionFailed() {
        Alert.alert(
            'Connection Failed',
            'There was a problem reaching our server. Please Try Again Later.',
            [{
                text: 'OK', 
                onPress: function() {this.dispatch(data.connectionFailed(1))}
            }],
            {cancelable: false},
        );
    }

    static init(room) {
        this.roomName = room;
        JitsiMeetJS.init(this.initOptions);
    }

    static makeConnection() {
        this.connection = new JitsiMeetJS.JitsiConnection(null, null, this.options);
        this.connection.connect();
    }

    static disconnect() {      
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, this.onConnectionSuccess);
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, this.onConnectionFailed);
      this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, this.disconnect);
    }

    static addEventListener() {
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, this.onConnectionSuccess);
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, this.onConnectionFailed);
        this.connection.addEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, this.disconnect);
    }

    static createLocalTracks(dispatcher) {
        this.dispatch = dispatcher;
        JitsiMeetJS.createLocalTracks({ devices: [ 'audio', 'video' ], facingMode: 'user' })
        .then(this.onLocalTracks)
        .catch(error = function() {
            throw error;
        });
    }

    static onSwitchCamera() {
        for (let i = 0; i < this.localTracks.length; i++) {
            if(this.localTracks[i].getType() === 'video'){
                this.localTracks[i]._switchCamera();
            }
        }
    }

    static onHangUp() {

        console.log("on hangup called");
        if(this.room){
            this.room.off(JitsiMeetJS.events.conference.TRACK_ADDED, this.onRemoteTrack);
            this.room.off(JitsiMeetJS.events.conference.TRACK_REMOVED, track = function() { console.info('track'); });
            this.room.off(JitsiMeetJS.events.conference.CONFERENCE_JOINED, this.onConferenceJoined);
            this.room.off(JitsiMeetJS.events.conference.USER_JOINED, id = function() { this.remoteTracks[id] = []; });
            this.room.off(JitsiMeetJS.events.conference.USER_LEFT, this.onUserLeft);
            this.room.off(JitsiMeetJS.events.conference.TRACK_MUTE_CHANGED, track = function() { console.info('track'); });
            this.room.off(JitsiMeetJS.events.conference.DISPLAY_NAME_CHANGED, function(userID, displayName) {console.info('displayName')});
            this.room.off(JitsiMeetJS.events.conference.TRACK_AUDIO_LEVEL_CHANGED, function(userID, audioLevel) {console.info('audioLevel')});
            this.room.leave().catch(function(e) {
                //console.log(e)
            });
            this.room = null;
        }
        
        if (this.connection) {
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_ESTABLISHED, this.onConnectionSuccess);
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_FAILED, this.onConnectionFailed);
            this.connection.removeEventListener(JitsiMeetJS.events.connection.CONNECTION_DISCONNECTED, this.disconnect);    
            this.connection.disconnect();
            this.connection = null;
        }
        if(this.dispatch !== null){
            this.dispatch(data.removeLocalTracks());
            this.dispatch(data.removeRemoteTracks());
            this.dispatch(data.addLocalUrl(''));
            this.dispatch(data.addRemoteUrl(''));
        }
    }
}